==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/outputs/GetNetworkInsightsAnalysisExplanationRouteTableRoute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property destinationCidr
 * @property destinationPrefixListId
 * @property egressOnlyInternetGatewayId
 * @property gatewayId
 * @property instanceId
 * @property natGatewayId
 * @property networkInterfaceId
 * @property origin
 * @property transitGatewayId
 * @property vpcPeeringConnectionId
 */
public data class GetNetworkInsightsAnalysisExplanationRouteTableRoute(
    public val destinationCidr: String,
    public val destinationPrefixListId: String,
    public val egressOnlyInternetGatewayId: String,
    public val gatewayId: String,
    public val instanceId: String,
    public val natGatewayId: String,
    public val networkInterfaceId: String,
    public val origin: String,
    public val transitGatewayId: String,
    public val vpcPeeringConnectionId: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.ec2.outputs.GetNetworkInsightsAnalysisExplanationRouteTableRoute):
            GetNetworkInsightsAnalysisExplanationRouteTableRoute =
            GetNetworkInsightsAnalysisExplanationRouteTableRoute(
                destinationCidr = javaType.destinationCidr(),
                destinationPrefixListId = javaType.destinationPrefixListId(),
                egressOnlyInternetGatewayId = javaType.egressOnlyInternetGatewayId(),
                gatewayId = javaType.gatewayId(),
                instanceId = javaType.instanceId(),
                natGatewayId = javaType.natGatewayId(),
                networkInterfaceId = javaType.networkInterfaceId(),
                origin = javaType.origin(),
                transitGatewayId = javaType.transitGatewayId(),
                vpcPeeringConnectionId = javaType.vpcPeeringConnectionId(),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/outputs/GetNetworkInsightsAnalysisExplanationRouteTableRoute.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 *
 * @property destinationCidr
 * @property destinationPrefixListId
 * @property egressOnlyInternetGatewayId
 * @property gatewayId
 * @property instanceId
 * @property natGatewayId
 * @property networkInterfaceId
 * @property origin
 * @property transitGatewayId
 * @property vpcPeeringConnectionId
 */
public data class GetNetworkInsightsAnalysisExplanationRouteTableRoute(
    public val destinationCidr: String,
    public val destinationPrefixListId: String,
    public val egressOnlyInternetGatewayId: String,
    public val gatewayId: String,
    public val instanceId: String,
    public val natGatewayId: String,
    public val networkInterfaceId: String,
    public val origin: String,
    public val transitGatewayId: String,
    public val vpcPeeringConnectionId: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.ec2.outputs.GetNetworkInsightsAnalysisExplanationRouteTableRoute): GetNetworkInsightsAnalysisExplanationRouteTableRoute =
            GetNetworkInsightsAnalysisExplanationRouteTableRoute(
                destinationCidr = javaType.destinationCidr(),
                destinationPrefixListId = javaType.destinationPrefixListId(),
                egressOnlyInternetGatewayId = javaType.egressOnlyInternetGatewayId(),
                gatewayId = javaType.gatewayId(),
                instanceId = javaType.instanceId(),
                natGatewayId = javaType.natGatewayId(),
                networkInterfaceId = javaType.networkInterfaceId(),
                origin = javaType.origin(),
                transitGatewayId = javaType.transitGatewayId(),
                vpcPeeringConnectionId = javaType.vpcPeeringConnectionId(),
            )
    }
}
